fn placeholders(base_url: &str, mail: &LinkingMailToQueue) -> ValueExpand description
Stored on the delivery row because the recipient may have no account here for the sender to read them from.
fn placeholders(base_url: &str, mail: &LinkingMailToQueue) -> ValueStored on the delivery row because the recipient may have no account here for the sender to read them from.